@@ -12,7 +12,7 @@ class JenkinsLibrary(JenkinsFace):
     | Library                | JenkinsLibrary   |
     |                        |
     | *** Test Cases ***     |
-    | create session jenkins | ${protocol}      | ${host}          | ${username}      | ${password}      |
+    | create session jenkins | ${protocol}      | ${host}          | ${username}      | ${password}      | ${verify} |
     | ${job_details}=        | Get Jenkins Job  | ${job_full_name} |
     | ${job_build_details}=  | Get Jenkins Job Build | ${job_full_name} | ${build_number}  |
     | ${build_number}=       | Build Jenkins With Parameters | ${job_full_name} | ${parameters_string} |
